@@ -5,14 +5,14 @@ from typing import TYPE_CHECKING
 if TYPE_CHECKING:
     from collections.abc import Iterator
 
-    from .handler import HandlerClass
+    from .handler import Handler
 
 
 class Handlers:
-    def __init__(self, *items: HandlerClass | Handlers) -> None:
+    def __init__(self, *items: Handler | Handlers) -> None:
         self.items = items
 
-    def __iter__(self) -> Iterator[HandlerClass]:
+    def __iter__(self) -> Iterator[Handler]:
         for item in self.items:
             if isinstance(item, Handlers):
                 yield from item
