@@ -1,10 +1,14 @@
 import telegram
 from telegram.helpers import create_deep_linked_url
 
+from botty.telegram_object import TelegramObject
+
+
+class Bot(TelegramObject):
+    raw: telegram.Bot
 
-class Bot:
     def __init__(self, raw: telegram.Bot) -> None:
-        self.raw = raw
+        super().__init__(raw)
 
     def get_start_url(self, payload: str = "0", *, group: bool = False) -> str:
         username = self.raw.username
